@@ -1,4 +1,5 @@
-import csv, pandas
+import csv
+import pandas
 
 def load_csv(path):
     with open(path,'rt')as f:
